@@ -143,7 +143,7 @@ int get_remote_file_data(FileData **remote_data)
 	FILE *fp;
 	char *fgets_temp;
 	char *file_name;
-	long date,time;
+	long date,mtime;
 	char mod_temp[20];
 	char dir_flag;
 	char *temp;
@@ -209,7 +209,7 @@ int get_remote_file_data(FileData **remote_data)
 			continue;
 		}
 
-		date=time=0;
+		date=mtime=0;
 		if(dir_flag!='d'){
 			if(conv_to_lower[host_number]){
 				temp=str_tolower(file_name);
@@ -217,11 +217,21 @@ int get_remote_file_data(FileData **remote_data)
 				free(file_name);
 				file_name=temp;
 			}
-			if(get_cache(file_name,&date,&time)==-1){
+			if(get_cache(file_name,&date,&mtime)==-1){
 				DebugPrint((stderr,"No cache: %s\n",file_name));
 				if(FtpModDate(file_name,mod_temp,20,ftp_buf)==1){
 					date=n_atol(mod_temp,8);
-					time=n_atol(mod_temp+8,6);
+					mtime=n_atol(mod_temp+8,6);
+					add_cache_num=str_realloc(add_cache_num,sizeof(*add_cache_num)*(add_cache_files+1));
+					add_cache_num[add_cache_files++]=file_num;
+				} else {
+					/* Ignore the MDTM failure and store the current date */
+					/* it would be better to use the LIST date ... */
+					time_t curtime = time(NULL);
+					struct tm *tmcur = gmtime(&curtime);
+
+					date=(1900+tmcur->tm_year)*10000 + (tmcur->tm_mon+1)*100 + (tmcur->tm_mday);
+					mtime=tmcur->tm_hour*10000 + tmcur->tm_min*100 + tmcur->tm_sec;
 					add_cache_num=str_realloc(add_cache_num,sizeof(*add_cache_num)*(add_cache_files+1));
 					add_cache_num[add_cache_files++]=file_num;
 				}
@@ -231,7 +241,7 @@ int get_remote_file_data(FileData **remote_data)
 
 		*remote_data=str_realloc(*remote_data,sizeof(**remote_data)*(file_num+1));
 		(*remote_data)[file_num].date=date;
-		(*remote_data)[file_num].time=time;
+		(*remote_data)[file_num].time=mtime;
 		(*remote_data)[file_num].isdir=(dir_flag=='d');
 		(*remote_data)[file_num].name=file_name;
 
